<?xml version='1.0'?>
<xsl:stylesheet version="1.0" 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
  xmlns:marc="http://www.loc.gov/MARC21/slim"
  xmlns:axsl="http://www.w3.org/1999/XSL/TransformAlias">
<xsl:namespace-alias stylesheet-prefix="axsl" result-prefix="xsl"/>
<xsl:output method="xml"/>

<xsl:template match="/">
  <!-- Stylesheet Header -->
  <axsl:stylesheet version="1.0" xmlns:marc="http://www.loc.gov/MARC21/slim">
    <xsl:element name="xsl:output">
      <xsl:attribute name="method">html</xsl:attribute>
    </xsl:element>

    <xsl:call-template name="Root"/>
    <xsl:call-template name="Leader"/>
    <xsl:call-template name="Controlfield"/>
    <xsl:call-template name="Datafield"/>
  </axsl:stylesheet>	
  <!-- Stylesheet Header End -->
</xsl:template>

<!-- Root Template -->
<xsl:template name="Root">
  <xsl:element name="xsl:template">
    <xsl:attribute name="match">/</xsl:attribute>
    
    <html>
      <xsl:element name="xsl:apply-templates"/>
    </html>
  </xsl:element>
</xsl:template>
<!-- Root Template End -->

<!-- Leader Template -->
<xsl:template name="Leader">
  <xsl:element name="xsl:template">
    <xsl:attribute name="match">marc:leader</xsl:attribute>

    <p>LEADER</p>

    <xsl:element name="xsl:variable">
      <xsl:attribute name="name">leader</xsl:attribute>
      <xsl:attribute name="select">text()</xsl:attribute>
    </xsl:element>
    <xsl:element name="xsl:variable">
      <xsl:attribute name="name">leader5</xsl:attribute>
      <xsl:attribute name="select">substring($leader, 6, 1)</xsl:attribute>
    </xsl:element>
    <xsl:element name="xsl:variable">
      <xsl:attribute name="name">leader6</xsl:attribute>
      <xsl:attribute name="select">substring($leader, 7, 1)</xsl:attribute>
    </xsl:element>
    <xsl:element name="xsl:variable">
      <xsl:attribute name="name">leader7</xsl:attribute>
      <xsl:attribute name="select">substring($leader, 8, 1)</xsl:attribute>
    </xsl:element>
    <xsl:element name="xsl:variable">
      <xsl:attribute name="name">leader8</xsl:attribute>
      <xsl:attribute name="select">substring($leader, 9, 1)</xsl:attribute>
    </xsl:element>
    <xsl:element name="xsl:variable">
      <xsl:attribute name="name">leader9</xsl:attribute>
      <xsl:attribute name="select">substring($leader, 10, 1)</xsl:attribute>
    </xsl:element>
    <xsl:element name="xsl:variable">
      <xsl:attribute name="name">leader17</xsl:attribute>
      <xsl:attribute name="select">substring($leader, 18, 1)</xsl:attribute>
    </xsl:element>
    <xsl:element name="xsl:variable">
      <xsl:attribute name="name">leader18</xsl:attribute>
      <xsl:attribute name="select">substring($leader, 19, 1)</xsl:attribute>
    </xsl:element>
    <xsl:element name="xsl:variable">
      <xsl:attribute name="name">leader19</xsl:attribute>
      <xsl:attribute name="select">substring($leader, 20, 1)</xsl:attribute>
    </xsl:element>

    <ul>
      <li>
        Record Status: 
        <xsl:element name="xsl:value-of">
          <xsl:attribute name="select">$leader5</xsl:attribute>
        </xsl:element>
      </li>
      <li>
        Type of Record: 
        <xsl:element name="xsl:value-of">
          <xsl:attribute name="select">$leader6</xsl:attribute>
        </xsl:element>
      </li>
      <li>
        Bibliographic Level: 
        <xsl:element name="xsl:value-of">
          <xsl:attribute name="select">$leader7</xsl:attribute>
        </xsl:element>
      </li>
      <li>
        Type of Control: 
        <xsl:element name="xsl:value-of">
          <xsl:attribute name="select">$leader8</xsl:attribute>
        </xsl:element>
      </li>
      <li>
        Undefined: 
        <xsl:element name="xsl:value-of">
          <xsl:attribute name="select">$leader9</xsl:attribute>
        </xsl:element>
      </li>
      <li>
        Encoding Level: 
        <xsl:element name="xsl:value-of">
          <xsl:attribute name="select">$leader17</xsl:attribute>
        </xsl:element>
      </li>
      <li>
        Descriptive Cataloging Form: 
        <xsl:element name="xsl:value-of">
          <xsl:attribute name="select">$leader18</xsl:attribute>
        </xsl:element>
      </li>
      <li>
        Linked Record Requirement: 
        <xsl:element name="xsl:value-of">
          <xsl:attribute name="select">$leader19</xsl:attribute>
        </xsl:element>
      </li>
    </ul>
  </xsl:element>
</xsl:template>
<!-- Leader Template End -->

<!-- Controlfield Template -->
<xsl:template name="Controlfield">
  <!-- References for the MARC21DOC -->
  <xsl:variable name="href">MARC21DOC.xml</xsl:variable>

  <xsl:call-template name="ControlfieldDetail">
    <xsl:with-param name="href">
      <xsl:value-of select="$href"/>
    </xsl:with-param>
  </xsl:call-template>
</xsl:template>
<!-- Controlfield Template End -->

<!-- ControlfieldDetail Template -->
<xsl:template name="ControlfieldDetail">
  <xsl:param name="href"/>

  <xsl:for-each select="document($href)/MARCDOC/FIELD">
    <xsl:variable name="tag" select="@tag"/>

    <xsl:if test="$tag &lt; 010">
      <xsl:element name="xsl:template">
        <xsl:attribute name="match">marc:controlfield[@tag = <xsl:value-of select="$tag"/>]</xsl:attribute>

        <p><xsl:value-of select="@name"/></p>
        <ul type="square">
          <li>
            <xsl:element name="xsl:value-of">
              <xsl:attribute name="select">text()</xsl:attribute>
            </xsl:element>
          </li>
        </ul>
      </xsl:element>
    </xsl:if>
  </xsl:for-each>
</xsl:template>
<!-- DatafieldDetail Template End -->

<!-- Datafield Template -->
<xsl:template name="Datafield">
  <!-- References for the MARC21DOC -->
  <xsl:variable name="href">MARC21DOC.xml</xsl:variable>

  <xsl:call-template name="DatafieldDetail">
    <xsl:with-param name="href">
      <xsl:value-of select="$href"/>
    </xsl:with-param>
  </xsl:call-template>
</xsl:template>
<!-- Datafield Template End -->

<!-- DatafieldDetail Template -->
<xsl:template name="DatafieldDetail">
  <xsl:param name="href"/>

  <xsl:for-each select="document($href)/MARCDOC/FIELD">
    <xsl:variable name="tag" select="@tag"/>

    <xsl:if test="$tag &gt; 009">
      <xsl:element name="xsl:template">
        <xsl:attribute name="match">marc:datafield[@tag = <xsl:value-of select="$tag"/>]</xsl:attribute>

        <p><xsl:value-of select="@name"/></p>
        <ul>
          <xsl:for-each select="SUBFIELD">
            <xsl:variable name="sfTag" select="@tag"/>

            <xsl:element name="xsl:for-each">
              <xsl:attribute name="select">marc:subfield[@code = '<xsl:value-of select="$sfTag"/>']</xsl:attribute>

              <li>
                <xsl:value-of select="@name"/>:
                <xsl:element name="xsl:value-of">
                  <xsl:attribute name="select">text()</xsl:attribute>
                </xsl:element>
              </li>
            </xsl:element>
          </xsl:for-each>
        </ul>
      </xsl:element>
    </xsl:if>
  </xsl:for-each>
</xsl:template>
<!-- DatafieldDetail Template End -->

</xsl:stylesheet><!-- Stylus Studio meta-information - (c)1998-2002 eXcelon Corp.
<metaInformation>
<scenarios ><scenario default="yes" name="Scenario1" userelativepaths="yes" externalpreview="no" url="MARC21DOC.xml" htmlbaseurl="" outputurl="" processortype="internal" commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext=""/></scenarios><MapperInfo srcSchemaPath="" srcSchemaRoot="" srcSchemaPathIsRelative="yes" srcSchemaInterpretAsXML="no" destSchemaPath="" destSchemaRoot="" destSchemaPathIsRelative="yes" destSchemaInterpretAsXML="no"/>
</metaInformation>
-->